@@ -9,13 +9,8 @@ cat <<EOF > $basedir/debian/tests/ApkVerifierTest.sh
 #!/bin/sh -e
 set -x
 
-if ! apksigner; then
-    echo "WARNING using local script hack, binfmt probably not setup"
-    test -e bin || mkdir bin
-    printf '#!/bin/sh -e\njava -jar /usr/bin/apksigner \$@\n' > bin/apksigner
-    chmod 0755 bin/apksigner
-    export PATH=\`pwd\`/bin:\$PATH
-fi
+# test -J args from apksigner shell script
+apksigner -JXmx256M verify src/test/resources/com/android/apksig/v1-only-with-rsa-pkcs1-sha384-1.2.840.113549.1.1.1-1024.apk
 
 EOF
 
